@@ -13,7 +13,7 @@ from twisted.internet import task
 from scrapy.logformatter import LogFormatter
 
 import scrapy_zen.signals
-from scrapy_zen.logging import ZenBufferedLogHandler
+from scrapy_zen.logging import ScrapyDictFormatter, ZenBufferedLogHandler
 
 
 logger = logging.getLogger(__name__)
@@ -110,9 +110,12 @@ class ZenBufferedLogs:
             raise NotConfigured
 
         buffer_length = crawler.settings.getint("ZEN_BUFFEREDLOGS_LENGTH", 30)
+        log_format = crawler.settings.get('LOG_FORMAT', '%(asctime)s [%(name)s] %(levelname)s: %(message)s')
+        log_dateformat = crawler.settings.get('LOG_DATEFORMAT', '%Y-%m-%d %H:%M:%S')
+        formatter = ScrapyDictFormatter(fmt=log_format, datefmt=log_dateformat)
         filename = pathlib.Path(log_file).stem + "_buffered.log"
         handler = ZenBufferedLogHandler(filename, buffer_length)
-        handler.setFormatter(crawler.logformatter)
+        handler.setFormatter(formatter)
 
         ext = cls(handler)
 
