@@ -17,6 +17,8 @@ from scrapy import Item, signals
 import websockets
 import logging
 
+import scrapy_zen.signals
+
 logging.getLogger("websockets").setLevel(logging.WARNING)
 logging.getLogger("pymongo").setLevel(logging.ERROR)
 
@@ -174,6 +176,12 @@ class PreProcessingPipeline(ItemValidationPipeline):
             item['published_at'] = None
         if self.settings.get("LOG_LEVEL","") == "INFO":
             spider.logger.info(item)
+
+        spider.crawler.signals.send_catch_log(
+            signal=scrapy_zen.signals.new_item,
+            item=item,
+            spider=spider
+        )
         return item
 
 
